{% load simple_translation_tags %}
<ul>
    {% for category in categories %}
        {% with category|get_preferred_translation_from_request:request as title %}
        <li><a href="{{ category.get_absolute_url }}">{{ title.title }}</a> ({{ category.num_posts }})</li>
        {% endwith %}
    {% endfor %}
</ul>
