{% load i18n cmsplugin_blog_tags %}
{% with category_entries as object_list %}
   {% if object_list %}
	  {% include "cmsplugin_blog/entry_list_include.html" %}
   {% else %}
	   <p>{% trans "No entries" %}</p>
   {% endif %}
{% endwith %}